pub struct DataNetwork;Trait Implementations
Sourceimpl Clone for DataNetwork
impl Clone for DataNetwork
impl Copy for DataNetwork
Sourceimpl Debug for DataNetwork
impl Debug for DataNetwork
impl Eq for DataNetwork
Sourceimpl Network for DataNetwork
impl Network for DataNetwork
Sourcetype TxEnvelope = EthereumTxEnvelope<TxEip4844Variant>
type TxEnvelope = EthereumTxEnvelope<TxEip4844Variant>
Sourcetype UnsignedTx = EthereumTypedTransaction<TxEip4844Variant>
type UnsignedTx = EthereumTypedTransaction<TxEip4844Variant>
Sourcetype ReceiptEnvelope = ReceiptEnvelope
type ReceiptEnvelope = ReceiptEnvelope
Sourcetype TransactionRequest = TransactionRequest
type TransactionRequest = TransactionRequest
Sourcetype TransactionResponse = Transaction
type TransactionResponse = Transaction
Sourcetype ReceiptResponse = TransactionReceipt
type ReceiptResponse = TransactionReceipt
Sourcetype HeaderResponse = Header
type HeaderResponse = Header
Sourcetype BlockResponse = Block<<DataNetwork as Network>::TransactionResponse, <DataNetwork as Network>::HeaderResponse>
type BlockResponse = Block<<DataNetwork as Network>::TransactionResponse, <DataNetwork as Network>::HeaderResponse>
Sourceimpl NetworkSpec for DataNetwork
impl NetworkSpec for DataNetwork
type HaltReason = HaltReason
fn encode_receipt(receipt: &Self::ReceiptResponse) -> Vec<u8> ⓘ
fn encode_transaction(tx: &Self::TransactionResponse) -> Vec<u8> ⓘ
fn is_hash_valid(block: &Self::BlockResponse) -> bool
fn receipt_contains( list: &[Self::ReceiptResponse], elem: &Self::ReceiptResponse, ) -> bool
fn receipt_logs(receipt: &Self::ReceiptResponse) -> Vec<Log>
fn transact<'life0, 'async_trait, E>(
tx: &'life0 Self::TransactionRequest,
validate_tx: bool,
execution: Arc<E>,
chain_id: u64,
fork_schedule: ForkSchedule,
block_id: BlockId,
state_overrides: Option<StateOverride>,
) -> Pin<Box<dyn Future<Output = Result<(ExecutionResult, HashMap<Address, Account>), EvmError>> + Send + 'async_trait>>where
E: 'async_trait + ExecutionProvider<Self>,
Self: 'async_trait,
'life0: 'async_trait,
Sourceimpl PartialEq for DataNetwork
impl PartialEq for DataNetwork
impl StructuralPartialEq for DataNetwork
Sourceimpl TransactionBuilder<DataNetwork> for TransactionRequest
impl TransactionBuilder<DataNetwork> for TransactionRequest
Sourcefn set_chain_id(&mut self, chain_id: ChainId)
fn set_chain_id(&mut self, chain_id: ChainId)
Sourcefn take_nonce(&mut self) -> Option<u64>
fn take_nonce(&mut self) -> Option<u64>
Sourcefn clear_kind(&mut self)
fn clear_kind(&mut self)
Sourcefn set_gas_price(&mut self, gas_price: u128)
fn set_gas_price(&mut self, gas_price: u128)
Sourcefn max_fee_per_gas(&self) -> Option<u128>
fn max_fee_per_gas(&self) -> Option<u128>
Sourcefn set_max_fee_per_gas(&mut self, max_fee_per_gas: u128)
fn set_max_fee_per_gas(&mut self, max_fee_per_gas: u128)
Sourcefn max_priority_fee_per_gas(&self) -> Option<u128>
fn max_priority_fee_per_gas(&self) -> Option<u128>
Sourcefn set_max_priority_fee_per_gas(&mut self, max_priority_fee_per_gas: u128)
fn set_max_priority_fee_per_gas(&mut self, max_priority_fee_per_gas: u128)
Sourcefn set_gas_limit(&mut self, gas_limit: u64)
fn set_gas_limit(&mut self, gas_limit: u64)
Sourcefn access_list(&self) -> Option<&AccessList>
fn access_list(&self) -> Option<&AccessList>
Sourcefn set_access_list(&mut self, access_list: AccessList)
fn set_access_list(&mut self, access_list: AccessList)
Sourcefn complete_type(&self, ty: TxType) -> Result<(), Vec<&'static str>>
fn complete_type(&self, ty: TxType) -> Result<(), Vec<&'static str>>
Sourcefn can_submit(&self) -> bool
fn can_submit(&self) -> bool
eth_sendTransaction endpoint.Sourcefn can_build(&self) -> bool
fn can_build(&self) -> bool
Sourcefn output_tx_type(&self) -> TxType
fn output_tx_type(&self) -> TxType
Sourcefn output_tx_type_checked(&self) -> Option<TxType>
fn output_tx_type_checked(&self) -> Option<TxType>
None if
the builder is not ready to build.Sourcefn prep_for_submission(&mut self)
fn prep_for_submission(&mut self)
Sourcefn build_unsigned(self) -> BuildResult<TypedTransaction, DataNetwork>
fn build_unsigned(self) -> BuildResult<TypedTransaction, DataNetwork>
Sourceasync fn build<W: NetworkWallet<DataNetwork>>(
self,
wallet: &W,
) -> Result<<DataNetwork as Network>::TxEnvelope, TransactionBuilderError<DataNetwork>>
async fn build<W: NetworkWallet<DataNetwork>>( self, wallet: &W, ) -> Result<<DataNetwork as Network>::TxEnvelope, TransactionBuilderError<DataNetwork>>
Sourcefn with_chain_id(self, chain_id: u64) -> Self
fn with_chain_id(self, chain_id: u64) -> Self
Sourcefn with_nonce(self, nonce: u64) -> Self
fn with_nonce(self, nonce: u64) -> Self
Sourcefn without_nonce(self) -> Self
fn without_nonce(self) -> Self
Sourcefn with_input<T>(self, input: T) -> Self
fn with_input<T>(self, input: T) -> Self
Sourcefn set_input_kind<T>(&mut self, input: T, _: TransactionInputKind)
fn set_input_kind<T>(&mut self, input: T, _: TransactionInputKind)
Sourcefn with_input_kind<T>(self, input: T, kind: TransactionInputKind) -> Self
fn with_input_kind<T>(self, input: T, kind: TransactionInputKind) -> Self
Sourcefn with_kind(self, kind: TxKind) -> Self
fn with_kind(self, kind: TxKind) -> Self
Sourcefn set_create(&mut self)
fn set_create(&mut self)
to field to a create call.Sourcefn into_create(self) -> Self
fn into_create(self) -> Self
to field to a create call.Sourcefn set_deploy_code<T>(&mut self, code: T)
fn set_deploy_code<T>(&mut self, code: T)
to field to TxKind::Create.Sourcefn with_deploy_code<T>(self, code: T) -> Self
fn with_deploy_code<T>(self, code: T) -> Self
to field to TxKind::Create.Sourcefn set_call<T>(&mut self, t: &T)where
T: SolCall,
fn set_call<T>(&mut self, t: &T)where
T: SolCall,
to field
if it is set to TxKind::Create.Sourcefn calculate_create_address(&self) -> Option<Address>
fn calculate_create_address(&self) -> Option<Address>
Sourcefn with_value(self, value: Uint<256, 4>) -> Self
fn with_value(self, value: Uint<256, 4>) -> Self
Sourcefn with_gas_price(self, gas_price: u128) -> Self
fn with_gas_price(self, gas_price: u128) -> Self
Sourcefn with_max_fee_per_gas(self, max_fee_per_gas: u128) -> Self
fn with_max_fee_per_gas(self, max_fee_per_gas: u128) -> Self
Sourcefn with_max_priority_fee_per_gas(self, max_priority_fee_per_gas: u128) -> Self
fn with_max_priority_fee_per_gas(self, max_priority_fee_per_gas: u128) -> Self
Sourcefn with_gas_limit(self, gas_limit: u64) -> Self
fn with_gas_limit(self, gas_limit: u64) -> Self
Sourcefn with_access_list(self, access_list: AccessList) -> Self
fn with_access_list(self, access_list: AccessList) -> Self
Sourcefn complete_preferred(&self) -> Result<(), Vec<&'static str>>
fn complete_preferred(&self) -> Result<(), Vec<&'static str>>
Sourcefn assert_preferred(&self, ty: <N as Network>::TxType)
fn assert_preferred(&self, ty: <N as Network>::TxType)
dbg_assert_eq! to check the builder status, and will have no affect
in release builds.Sourcefn assert_preferred_chained(self, ty: <N as Network>::TxType) -> Self
fn assert_preferred_chained(self, ty: <N as Network>::TxType) -> Self
dbg_assert_eq! to check the builder status, and will have no affect
in release builds.Auto Trait Implementations
impl Freeze for DataNetwork
impl RefUnwindSafe for DataNetwork
impl Send for DataNetwork
impl Sync for DataNetwork
impl Unpin for DataNetwork
impl UnsafeUnpin for DataNetwork
impl UnwindSafe for DataNetwork